==> ZenTaoPMS.pro8.9.4.php7.1.zip: zentaopms/module/caselib/lang/zh-tw.php <==
<?php
/**
 * The caselib module zh-tw file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青島易軟天創網絡科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL (http://zpl.pub/page/zplv12.html)
 * @author      Yidong Wang <yidong@cnezsoft.com>
 * @package     caselib
 * @version     $Id: zh-tw.php 4490 2013-02-27 03:27:05Z wyd621@gmail.com $
 * @link        http://www.zentao.net
 */
$lang->caselib->common = '用例庫';
$lang->caselib->all    = '所有用例庫';

$lang->caselib->index            = "用例庫首頁";
$lang->caselib->create           = "創建用例庫";
$lang->caselib->edit             = '編輯用例庫';
$lang->caselib->browse           = '瀏覽庫用例';
$lang->caselib->view             = '查看庫概況';
$lang->caselib->createCase       = '創建用例';
$lang->caselib->delete           = "刪除";
$lang->caselib->linkVersion      = "版本";
$lang->caselib->deleted          = '已刪除';
$lang->caselib->exportTemplet    = '導出模板';
$lang->caselib->batchCreateCase  = '批量創建用例';
$lang->caselib->import           = '導入';
$lang->caselib->importAction     = '導入用例';
$lang->caselib->showImport       = '顯示導入數據';

$lang->caselib->id             = '編號';
$lang->caselib->name           = '名稱';
$lang->caselib->desc           = '描述';
$lang->caselib->addedBy        = '由誰創建';
$lang->caselib->addedDate      = '創建時間';
$lang->caselib->lastEditedBy   = '最後編輯人';
$lang->caselib->lastEditedDate = '最後編輯時間';

$lang->caselib->legendDesc = '描述';

$lang->caselib->libraryDelete = '您確認要刪除該用例庫嗎？';
$lang->caselib->noModule      = '<div>您現在還沒有模組信息</div><div>請維護用例庫模組</div>';

==> ZenTaoPMS.pro10.0.rc1.php5.3_5.6.zip: zentaopms/module/caselib/lang/zh-tw.php <==
<?php
/**
 * The caselib module zh-tw file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青島易軟天創網絡科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL (http://zpl.pub/page/zplv12.html)
 * @author      Yidong Wang <yidong@cnezsoft.com>
 * @package     caselib
 * @version     $Id: zh-tw.php 4490 2013-02-27 03:27:05Z wyd621@gmail.com $
 * @link        http://www.zentao.net
 */
$lang->caselib->common = '用例庫';
$lang->caselib->all    = '所有用例庫';

$lang->caselib->index            = "用例庫首頁";
$lang->caselib->create           = "創建用例庫";
$lang->caselib->edit             = '編輯用例庫';
$lang->caselib->browse           = '瀏覽用例庫';
$lang->caselib->view             = '查看庫概況';
$lang->caselib->createCase       = '創建用例';
$lang->caselib->delete           = "刪除";
$lang->caselib->linkVersion      = "版本";
$lang->caselib->deleted          = '已刪除';
$lang->caselib->exportTemplet    = '導出模板';
$lang->caselib->batchCreateCase  = '批量創建用例';
$lang->caselib->import           = '導入';
$lang->caselib->showImport       = '顯示導入數據';

$lang->caselib->browseAction     = '用例庫列表';
$lang->caselib->deleteAction     = "刪除用例庫";
$lang->caselib->importAction     = '導入用例';
$lang->caselib->linkVersion      = "版本";

$lang->caselib->id             = '編號';
$lang->caselib->name           = '名稱';
$lang->caselib->desc           = '描述';
$lang->caselib->addedBy        = '由誰創建';
$lang->caselib->addedDate      = '創建時間';
$lang->caselib->lastEditedBy   = '最後編輯人';
$lang->caselib->lastEditedDate = '最後編輯時間';

$lang->caselib->legendDesc = '描述';

$lang->caselib->libraryDelete = '您確認要刪除該用例庫嗎？';
$lang->caselib->noModule      = '<div>您現在還沒有模組信息</div><div>請維護用例庫模組</div>';
